gridrho_f: Support function for 'ui_causal'

View source: R/gridrho_f.R

gridrho_fR Documentation

Support function for ui_causal

Description

Divides the rho interval into a grid

Usage

gridrho_f(rho, gridn, rho_plotrange, plot)

Arguments

rho

interval that should be divided

gridn

number of gridpoints

rho_plotrange

a larger interval of grids to be used in a plot

plot

whether or not the larger interval of grids should be created


ui documentation built on June 25, 2026, 5:09 p.m.

Related to gridrho_f in ui...