logl_sand_act: Loglikelohood used in sandwich estimator of average causal...

View source: R/logl_sand_act.R

logl_sand_actR Documentation

Loglikelohood used in sandwich estimator of average causal effect on the treated for DR

Description

Loglikelohood used in sandwich estimator of average causal effect on the treated for DR, support function for ui_causal

Usage

logl_sand_act(x, X, z)

Arguments

x

coefficents.

X

Covariate matrix.

z

Missing or not.


ui documentation built on June 25, 2026, 5:09 p.m.

Related to logl_sand_act in ui...