ml_probit: Fit maximum likelihood for fixed values of rho

View source: R/ml_probit.R

ml_probitR Documentation

Fit maximum likelihood for fixed values of rho

Description

This is a support function for ui_probit

Usage

ml_probit(out_formula, mis_formula, data, rho, progress = TRUE, method = "NR")

Arguments

out_formula

Formula for outcome regression.

mis_formula

Formula for regression model for the missingness mechanism.

data

Data frame containing the variables in the formulas

rho

Vector containing the values of rho for which we want to fit the likelihood.

progress

If TRUE prints out process time for each maximazation of the likelihood.

method

Maximazation method to be passed through maxLik


ui documentation built on June 25, 2026, 5:09 p.m.

Related to ml_probit in ui...