plot.uiprobit: Plot of UI and CI

View source: R/plot.uiprobit.R

plot.uiprobitR Documentation

Plot of UI and CI

Description

Plot function for objects returned from ui_probit.Plots confidence intervals, coefficients and significance assuming ignorability and the uncertainty interval under non-ignorability.

Usage

## S3 method for class 'uiprobit'
plot(
  x,
  plot.all = TRUE,
  which = NA,
  intercept = FALSE,
  ylab = NULL,
  col = c("black", "royalblue", "lightpink2"),
  ...
)

Arguments

x

An object of class uiprobit

plot.all

If TRUE, plots all covariates.

which

Specify which variables should be plotted by either sending in their names in a vector or a vector with their numbers (1 for the first covariate, 2 for the second etc.).To plot the intercept, set intercept as TRUE.

intercept

If TRUE, also plots the intercept.

ylab

Vector of names for the y-axis, default is the variable names.

col

Vector containing the color of estimates under MAR and bounds of estimate under MNAR (default black), confidence intervals (default royalblue) and uncertainty intervals (default lightpink2).

...

Additional arguments, use is discouraged.


ui documentation built on June 25, 2026, 5:09 p.m.

Related to plot.uiprobit in ui...