View source: R/print.uicausal.R
| print.uicausal | R Documentation |
Print function for object of class uicausal
## S3 method for class 'uicausal'
print(x, digits = 3, digitsci = digits, digitsui = digits, ...)
x |
An object of returned from |
digits |
number of digits to be printed. |
digitsci |
number of digits to be printed in the confidence interval. |
digitsui |
number of digits to be printed in the uncertainty interval. |
... |
Additional arguments, use is discouraged. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.