profile.uicausal: Plot of UI and CI

View source: R/profile.uicausal.R

profile.uicausalR Documentation

Plot of UI and CI

Description

Plot function for objects returned from ui_causal. Plots confidence intervals for different values of rho and the uncertainty interval.

Usage

## S3 method for class 'uicausal'
profile(
  x,
  dr = TRUE,
  profile = "all",
  title = NULL,
  xlab = NULL,
  ylab = NULL,
  ...
)

Arguments

x

An object of class uicausal

dr

If TRUE the doubly robust estimator is plotted, otherwise the outcome regression estimator is plotted.

profile

Character specifying profile type ("ui.only" or "all"). If ui.only, only the UI range is plotted; if all, the full profile is shown.

title

Main title

xlab

Title for xaxis, default is expression(rho).

ylab

Title for y axis, default is no title.

...

discouraged from use


ui documentation built on June 25, 2026, 5:09 p.m.

Related to profile.uicausal in ui...