profile.uiols: Plot of UI and CI

View source: R/profile.uiols.R

profile.uiolsR Documentation

Plot of UI and CI

Description

Plot function for objects returned from ui_ols. Plots confidence intervals for different values of rho and the uncertainty interval.

Usage

## S3 method for class 'uiols'
profile(
  x,
  plot.all = TRUE,
  which = NA,
  intercept = FALSE,
  xlab = NULL,
  ylab = NULL,
  scales = "fixed",
  expand = 0.1,
  ...
)

Arguments

x

An object of class uiols

plot.all

If TRUE, plots all covariates.

which

Specify which variables should be plotted by either sending in their names in a vector or a vector with their numbers (1 intercept, 2 for the first covariate etc.).

intercept

If TRUE, also plots the intercept.

xlab

Title for x-axis, default is expression(rho).

ylab

Title for y-axis, default is the variable names.

scales

Fixed or different scales of the y axis between panels. Default is "fixed", the other choice is "free_y".

expand

Add space by expanding y-axis range. Default is 0.1 which is 10% extra on above and below.

...

Additional arguments, use is discouraged.


ui documentation built on June 25, 2026, 5:09 p.m.

Related to profile.uiols in ui...