profile.uipcor: Plot of confidence intervals for partial correlation by...

View source: R/profile.uipcor.R

profile.uipcorR Documentation

Plot of confidence intervals for partial correlation by values of the sensitivity parameter (s).

Description

Plots confidence intervals by values of sensitivity parameter (s) for objects returned from ui_pcor.

Usage

## S3 method for class 'uipcor'
profile(x, ...)

Arguments

x

An object of class uipcor

...

Additional arguments, for instance margins.

Details

Plots estimated partial correlation, lower and upper bounds of confidence intervals for different values of rho (based on on values of the sensitivity parameter(s) in x$gridrho). Plots a 2D plot when missing data only in the outcome or the same missing in the outcome and the predictor of interest (missing data mechanisms A and B). Plots a 3D plot when different missing data in the outcome and the predictor of interest (missing data mechanism C).


ui documentation built on June 25, 2026, 5:09 p.m.

Related to profile.uipcor in ui...