sand_or_act: Calculates standard error of Average causal effect on the...

View source: R/sand_or_act.R

sand_or_actR Documentation

Calculates standard error of Average causal effect on the treated

Description

This is a support function for ui_causal and calculates standard error of Average causal effect on the treated for the outcome regression estimator.

Usage

sand_or_act(X, y, z, BetaOLSy0, NaivEst, n1, N, p)

Arguments

X

Covariate matrix.

y

Outcome vector.

z

missingness indicator

BetaOLSy0

Coefficients from non-treated regression

NaivEst

Naiv estimates.

n1

Number of treated.

N

Total number.

p

Number of covariates outcome regression.


ui documentation built on June 25, 2026, 5:09 p.m.

Related to sand_or_act in ui...