| ml_probit | R Documentation |
This is a support function for ui_probit
ml_probit(out_formula, mis_formula, data, rho, progress = TRUE, method = "NR")
out_formula |
Formula for outcome regression. |
mis_formula |
Formula for regression model for the missingness mechanism. |
data |
Data frame containing the variables in the formulas |
rho |
Vector containing the values of rho for which we want to fit the likelihood. |
progress |
If TRUE prints out process time for each maximazation of the likelihood. |
method |
Maximazation method to be passed through |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.