| plot.uiols | R Documentation |
Plot function for objects returned from ui_ols. Plots confidence intervals,
coefficients and significance assuming ignorability and the uncertainty interval under non-ignorability.
## S3 method for class 'uiols'
plot(
x,
plot.all = TRUE,
which = NA,
intercept = FALSE,
ylab = NULL,
col = c("black", "royalblue", "lightpink2"),
...
)
x |
An object of class uiols |
plot.all |
If TRUE, plots all covariates. |
which |
Specify which variables should be plotted by either sending in their names in a vector or a vector with their numbers (1 intercept, 2 for the first covariate etc.). |
intercept |
If TRUE, also plots the intercept. |
ylab |
Vector of names for the y-axis, default is the variable names. |
col |
Vector containing the color of estimates under MAR and bounds of estimate under MNAR (default black), confidence intervals (default royalblue) and uncertainty intervals (default lightpink2). |
... |
Additional arguments, use is discouraged. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.