View source: R/profile.uicausal.R
| profile.uicausal | R Documentation |
Plot function for objects returned from ui_causal.
Plots confidence intervals for different values of rho and the uncertainty interval.
## S3 method for class 'uicausal'
profile(
x,
dr = TRUE,
profile = "all",
title = NULL,
xlab = NULL,
ylab = NULL,
...
)
x |
An object of class uicausal |
dr |
If TRUE the doubly robust estimator is plotted, otherwise the outcome regression estimator is plotted. |
profile |
Character specifying profile type ( |
title |
Main title |
xlab |
Title for xaxis, default is |
ylab |
Title for y axis, default is no title. |
... |
discouraged from use |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.