View source: R/profile.uiols.R
| profile.uiols | R Documentation |
Plot function for objects returned from ui_ols.
Plots confidence intervals for different values of rho and the uncertainty interval.
## S3 method for class 'uiols'
profile(
x,
plot.all = TRUE,
which = NA,
intercept = FALSE,
xlab = NULL,
ylab = NULL,
scales = "fixed",
expand = 0.1,
...
)
x |
An object of class uiols |
plot.all |
If TRUE, plots all covariates. |
which |
Specify which variables should be plotted by either sending in their names in a vector or a vector with their numbers (1 intercept, 2 for the first covariate etc.). |
intercept |
If TRUE, also plots the intercept. |
xlab |
Title for x-axis, default is |
ylab |
Title for y-axis, default is the variable names. |
scales |
Fixed or different scales of the y axis between panels. Default is "fixed", the other choice is "free_y". |
expand |
Add space by expanding y-axis range. Default is 0.1 which is 10% extra on above and below. |
... |
Additional arguments, use is discouraged. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.