View source: R/profile.uipcor.R
| profile.uipcor | R Documentation |
Plots confidence intervals by values of sensitivity parameter (s) for objects returned from ui_pcor.
## S3 method for class 'uipcor'
profile(x, ...)
x |
An object of class uipcor |
... |
Additional arguments, for instance margins. |
Plots estimated partial correlation, lower and upper bounds of confidence intervals for different values of rho (based on on values of the sensitivity parameter(s) in x$gridrho).
Plots a 2D plot when missing data only in the outcome or the same missing in the outcome and the predictor of interest (missing data mechanisms A and B).
Plots a 3D plot when different missing data in the outcome and the predictor of interest (missing data mechanism C).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.